OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Grāmatzīmes",
    "No file provided for import" : "Nav norādīta importējamā datne",
    "Bookmark" : "Grāmatzīme",
    "Details" : "Detaļas",
    "Rename" : "Pārsaukt",
    "Copy link" : "Kopēt saiti",
    "Move" : "Pārvietot",
    "Select all" : "Atzīmēt visu",
    "Go back" : "Atpakaļ",
    "New" : "Jauns",
    "New folder" : "Jauna mape",
    "Search" : "Meklēt",
    "Empty trash bin" : "Izdzēst miskastes saturu",
    "Add a bookmark" : "Pievienot grāmatzīmi",
    "Rename folder" : "Pārsaukt mapi",
    "Choose folder" : "Izvēlēties mapi",
    "Submit" : "Iesniegt",
    "Cancel" : "Atcelt",
    "Recent" : "Nesenās",
    "Shared with you" : "Koplietots ar jums",
    "Files" : "Datnes",
    "Delete" : "Dzēst",
    "Bookmarklet" : "Grāmatzīme",
    "Need help?" : "Vajadzīga palīdzība?",
    "Title" : "Amats",
    "Link" : "Saite",
    "Tags" : "Birkas",
    "Notes" : "Piezīmes",
    "Notes for this bookmark …" : "Šīs grāmatzīmes piezīmes …",
    "Download file" : "Lejupielādēt datni",
    "Owner" : "Īpašnieks",
    "Sharing" : "Koplietošana",
    "Share link" : "Koplietot saiti",
    "Allow editing" : "Atļaut labošanu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Link copied" : "Saite nokopēta",
    "Privacy" : "Privātums",
    "Previews" : "Priekšskatījumi",
    "Screeenly API URL" : "Screeenly API saite",
    "Screeenly API key" : "Screeenly API atslēga",
    "Failed to save settings" : "Neizdevās saglabāt iestatījumus",
    "This URL is already bookmarked! Overwrite?" : "Šī saite jau ir grāmatzīmēs! Vai pārrakstīt?",
    "Folder" : "Mape",
    "Save" : "Saglabāt",
    "Bookmarks feed" : "Grāmatzīmju plūsma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
